@@ -568,9 +568,10 @@ class StandardActionManager::Private
       if ( !canCreateCollection( parentCollection ) )
         return;
 
-      const QString name = KInputDialog::getText( contextText( StandardActionManager::CreateCollection, StandardActionManager::DialogTitle ),
+      QString name = KInputDialog::getText( contextText( StandardActionManager::CreateCollection, StandardActionManager::DialogTitle ),
                                                   contextText( StandardActionManager::CreateCollection, StandardActionManager::DialogText ),
                                                   QString(), 0, parentWidget );
+      name = name.trimmed();
       if ( name.isEmpty() )
         return;
 
@@ -578,7 +579,11 @@ class StandardActionManager::Private
         KMessageBox::error( parentWidget,
                             i18n( "We can not add \"/\" in folder name." ),
                             i18n( "Create new folder error" ) );
-
+        return;
+      }
+      if ( name.startsWith( QLatin1Char('.') ) ||
+           name.endsWith( QLatin1Char('.') ) ) {
+          kDebug()<<" We can not add \".\" at begin or end of folder name ";
         return;
       }
 
@@ -768,7 +773,7 @@ class StandardActionManager::Private
     {
       Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance( collection.resource() );
       if ( !instance.isOnline() ) {
-        if ( KMessageBox::questionYesNo( parentWidget, i18n( "Before to sync folder \"%1\" it's necessary to have resource online. Do you want to make it online?" , collection.name()  ), i18n( "Account \"%1\" is offline", instance.name() ) ) != KMessageBox::Yes )
+        if ( KMessageBox::questionYesNo( parentWidget, i18n( "Before syncing folder \"%1\" it's necessary to have resource online. Do you want to make it online?" , collection.name()  ), i18n( "Account \"%1\" is offline", instance.name() ) ) != KMessageBox::Yes )
           return false;
         instance.setIsOnline( true );
       }
